==> moodle-1.4.3.tgz: moodle/lang/nl/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004093001)


$string['asset'] = 'Bezit';
$string['attr_error'] = 'Foute waarde voor attribuut ($a->attr) in tag $a->tag.';
$string['autocontinue'] = 'Ga automatisch verder';
$string['badmanifest'] = 'Enkele belangrijke fouten: zie foutenlogboek';
$string['browse'] = 'Bladeren';
$string['browsed'] = 'Gebladerd';
$string['browsemode'] = 'Bladermodus';
$string['chooseapacket'] = 'Kies of update een SCORM-pakket';
$string['completed'] = 'Volledig';
$string['configframesize'] = 'Deze waarde is de grootte (in pixels) van het bovenste frame (waarin de navigatie zit) wanneer je een SCORM-pakket toont.';
$string['configpopup'] = 'Wanneer je een nieuw SCORM-pakket toevoegt dat in een popup-scherm getoond kan worden, wil je dan standaard deze optie inschakelen?';
$string['configpopupheight'] = 'Welke hoogte wil je als standaardwaarde voor nieuwe popup-schermen?';
$string['configpopupresizable'] = 'Wil je als standaardinstelling dat de grootte van popup-schermen kan gewijzigd worden?';
$string['configpopupscrollbars'] = 'Wil je als standaardinstelling dat in popup-schermen gescrolled kan worden?';
$string['configpopupstatus'] = 'Wil je als standaardinstelling dat popup-schermen de statusbalk tonen?';
$string['configpopupwidth'] = 'Welke breedte wil je als standaardwaarde voor nieuwe popup-schermen?';
$string['coursepacket'] = 'Cursuspakket';
$string['coursestruct'] = 'cursusstructuur';
$string['datadir'] = 'Fout van het bestandssysteem: de gegevensfolder van de cursus kan niet gemaakt worden';
$string['domxml'] = 'DOMXML externe bibliotheek';
$string['entercourse'] = 'Voeg een SCORM-cursus toe';
$string['errorlogs'] = 'Foutenlogboek';
$string['failed'] = 'Mislukt';
$string['found'] = 'Manifest gevonden';
$string['gradeaverage'] = 'Gemiddeld cijfer';
$string['gradehighest'] = 'Hoogste cijfer';
$string['grademethod'] = 'Beoordelingsmethode';
$string['gradescoes'] = 'situatie van de scoes';
$string['gradesum'] = 'Totaalcijfer';
$string['guestsno'] = 'Gasten kunnen SCORM-lessen niet bekijken';
$string['incomplete'] = 'Onvolledig';
$string['missing_attribute'] = 'Attribuut ontbreekt $a->attr in tag $a->tag';
$string['missing_tag'] = 'Ontbrekende tag $a->tag';
$string['mode'] = 'Modus';
$string['modulename'] = 'SCORM';
$string['modulenameplural'] = 'SCORMS';
$string['newheight'] = 'Standaardvensterhoogte (in pixels)';
$string['newresizable'] = 'Groote van het venster mag gewijzigd worden';
$string['newscrollbars'] = 'Scrollen in het venster mag';
$string['newstatus'] = 'Toon de statusbalk';
$string['newwidth'] = 'Standaardvensterbreedte (in pixels)';
$string['newwindow'] = 'Nieuw venster';
$string['newwindowopen'] = 'Toon dit SCORM-pakket in een nieuw popup-scherm';
$string['next'] = 'Ga verder';
$string['no_attributes'] = 'Tag $a->tag moet attributen hebben';
$string['no_children'] = 'Tag $a->tag moet children hebben';
$string['nomanifest'] = 'Manifest niet gevonden';
$string['noreports'] = 'Er is geen rapport om te tonen';
$string['normal'] = 'Normaal';
$string['not_corr_type'] = 'Typfout voor tag $a->tag';
$string['notattempted'] = 'Niet geprobeerd';
$string['organizations'] = 'Organisaties';
$string['packagedir'] = 'Fout van het bestandssysteem: kan geen map voor het pakket maken';
$string['passed'] = 'Geslaagd';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['position_error'] = 'De $a->tag kan geen child zijn van $a->parent tag';
$string['prev'] = 'Vorige';
$string['regular'] = 'Normaal manifest';
$string['report'] = 'Rapport';
$string['review'] = 'Herzien';
$string['scoes'] = 'Scoes';
$string['score'] = 'Score';
$string['syntax'] = 'Syntaxfout';
$string['tag_error'] = 'Onbekende tag ($a->tag) met deze inhoud: $a->value';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Nederlands';
$string['too_many_attributes'] = 'Tag $a->tag heeft te veel attributen';
$string['too_many_children'] = 'Tag $a->tag heeft teveel children';
$string['trackingloose'] = 'WAARSCHUWING: de gegevens voor opvolging van dit SCORM-pakket zullen verloren gaan';
$string['validateascorm'] = 'Bevestig een SCORM-pakket';
$string['validation'] = 'Bevestigingsresultaat';
$string['validationtype'] = 'Deze instelling maakt dat de DOMXML-bibliotheek gebruikt wordt voor de validatie van het SCORM MAnifest. Als je twijfelt laat dan de geselecteerde keuze staan.';
$string['versionwarning'] = 'De versie van het Manifest is ouder dan 1.3, waarschuwing bij tag $a->tag';
$string['viewallreports'] = 'Bekijk de rapporten voor $a pogingen';

?>

==> moodle-1.5.3.tgz: moodle/lang/nl/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.6 development (2005060201)


$string['advanced'] = 'Geavanceerd';
$string['asset'] = 'Bezit';
$string['attr_error'] = 'Foute waarde voor attribuut ($a->attr) in tag $a->tag.';
$string['autocontinue'] = 'Ga automatisch verder';
$string['badmanifest'] = 'Enkele belangrijke fouten: zie foutenlogboek';
$string['browse'] = 'Bladeren';
$string['browsed'] = 'Gebladerd';
$string['browsemode'] = 'Bladermodus';
$string['chooseapacket'] = 'Kies of update een SCORM-pakket';
$string['completed'] = 'Volledig';
$string['coursepacket'] = 'Cursuspakket';
$string['coursestruct'] = 'cursusstructuur';
$string['datadir'] = 'Fout van het bestandssysteem: de gegevensfolder van de cursus kan niet gemaakt worden';
$string['details'] = 'SCO opvolgdetails';
$string['display'] = 'Toon';
$string['domxml'] = 'DOMXML externe bibliotheek';
$string['enablebrowse'] = 'Maak op voorhand kijken mogelijk';
$string['entercourse'] = 'Voeg een SCORM-cursus toe';
$string['errorlogs'] = 'Foutenlogboek';
$string['exit'] = 'Verlaat de SCORM-cursus';
$string['expcoll'] = 'Maximaliseer/Minimaliseer';
$string['failed'] = 'Mislukt';
$string['firstaccess'] = 'Eerste toegang';
$string['found'] = 'Manifest gevonden';
$string['frameheight'] = 'Met deze instelling kies je de hoogte van het SCO frame';
$string['framewidth'] = 'Deze voorkeurinstelling is de standaardbreedte van het SCO-frame';
$string['gradeaverage'] = 'Gemiddeld cijfer';
$string['gradehighest'] = 'Hoogste cijfer';
$string['grademethod'] = 'Beoordelingsmethode';
$string['gradescoes'] = 'SCO-toestand';
$string['gradesum'] = 'Totaalcijfer';
$string['guestsno'] = 'Gasten kunnen SCORM-lessen niet bekijken';
$string['height'] = 'Hoogte';
$string['incomplete'] = 'Onvolledig';
$string['lastaccess'] = 'Laatste toegang';
$string['missing_attribute'] = 'Attribuut ontbreekt $a->attr in tag $a->tag';
$string['missing_tag'] = 'Ontbrekende tag $a->tag';
$string['mode'] = 'Modus';
$string['modulename'] = 'SCORM';
$string['modulenameplural'] = 'SCORMS';
$string['next'] = 'Ga verder';
$string['no_attributes'] = 'Tag $a->tag moet attributen hebben';
$string['no_children'] = 'Tag $a->tag moet children hebben';
$string['noactivity'] = 'Niets te melden';
$string['nomanifest'] = 'Manifest niet gevonden';
$string['noreports'] = 'Er is geen rapport om te tonen';
$string['normal'] = 'Normaal';
$string['not_corr_type'] = 'Typfout voor tag $a->tag';
$string['notattempted'] = 'Niet geprobeerd';
$string['organization'] = 'Organisatie';
$string['organizations'] = 'Organisaties';
$string['packagedir'] = 'Fout van het bestandssysteem: kan geen map voor het pakket maken';
$string['packagefile'] = 'Je hebt geen bestand met een pakket gespecifieerd';
$string['passed'] = 'Geslaagd';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['popup'] = 'Open de huidige SCO in een nieuw venster';
$string['position_error'] = 'De $a->tag kan geen child zijn van $a->parent tag';
$string['prev'] = 'Vorige';
$string['regular'] = 'Normaal manifest';
$string['report'] = 'Rapport';
$string['review'] = 'Herzien';
$string['scoes'] = 'Scoes';
$string['score'] = 'Score';
$string['scormcourse'] = 'SCORM cursus';
$string['stagesize'] = 'Frame- / venstergrootte';
$string['syntax'] = 'Syntaxfout';
$string['tag_error'] = 'Onbekende tag ($a->tag) met deze inhoud: $a->value';
$string['too_many_attributes'] = 'Tag $a->tag heeft te veel attributen';
$string['too_many_children'] = 'Tag $a->tag heeft teveel children';
$string['totaltime'] = 'Tijd';
$string['trackingloose'] = 'WAARSCHUWING: de gegevens voor opvolging van dit SCORM-pakket zullen verloren gaan';
$string['validateascorm'] = 'Bevestig een SCORM-pakket';
$string['validation'] = 'Bevestigingsresultaat';
$string['validationtype'] = 'Deze instelling maakt dat de DOMXML-bibliotheek gebruikt wordt voor de validatie van het SCORM MAnifest. Als je twijfelt laat dan de geselecteerde keuze staan.';
$string['versionwarning'] = 'De versie van het Manifest is ouder dan 1.3, waarschuwing bij tag $a->tag';
$string['viewallreports'] = 'Bekijk de rapporten voor $a pogingen';
$string['width'] = 'Breedte';

?>
